==> svm-19.3.6-sources.jar: com/oracle/svm/core/code/CodeInfoMemoryWalker.java <==
/*
 * Copyright (c) 2019, 2019, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */
package com.oracle.svm.core.code;

import org.graalvm.nativeimage.ImageSingletons;
import org.graalvm.nativeimage.Platform;
import org.graalvm.nativeimage.Platforms;
import org.graalvm.nativeimage.hosted.Feature;
import org.graalvm.word.UnsignedWord;

import com.oracle.svm.core.MemoryWalker;
import com.oracle.svm.core.annotate.AutomaticFeature;

final class CodeInfoMemoryWalker implements MemoryWalker.CodeAccess<CodeInfo> {

    @Platforms(Platform.HOSTED_ONLY.class)
    CodeInfoMemoryWalker() {
    }

    @Override
    public UnsignedWord getStart(CodeInfo codeInfo) {
        return (UnsignedWord) CodeInfoAccess.getCodeStart(codeInfo);
    }

    @Override
    public UnsignedWord getSize(CodeInfo codeInfo) {
        return CodeInfoAccess.getCodeSize(codeInfo);
    }

    @Override
    public UnsignedWord getMetadataSize(CodeInfo codeInfo) {
        return CodeInfoAccess.getMetadataSize(codeInfo);
    }

    @Override
    public String getName(CodeInfo codeInfo) {
        return CodeInfoAccess.getName(codeInfo);
    }
}

@AutomaticFeature
class CodeInfoMemoryWalkerFeature implements Feature {
    @Override
    public void beforeAnalysis(BeforeAnalysisAccess access) {
        ImageSingletons.add(CodeInfoMemoryWalker.class, new CodeInfoMemoryWalker());
    }
}

==> svm-21.1.0-sources.jar: com/oracle/svm/core/code/CodeInfoMemoryWalker.java <==
/*
 * Copyright (c) 2019, 2019, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */
package com.oracle.svm.core.code;

import org.graalvm.nativeimage.ImageSingletons;
import org.graalvm.nativeimage.Platform;
import org.graalvm.nativeimage.Platforms;
import org.graalvm.nativeimage.hosted.Feature;
import org.graalvm.word.UnsignedWord;

import com.oracle.svm.core.MemoryWalker;
import com.oracle.svm.core.annotate.AutomaticFeature;

final class CodeInfoMemoryWalker implements MemoryWalker.CodeAccess<CodeInfo> {

    @Platforms(Platform.HOSTED_ONLY.class)
    CodeInfoMemoryWalker() {
    }

    @Override
    public UnsignedWord getStart(CodeInfo codeInfo) {
        return (UnsignedWord) CodeInfoAccess.getCodeStart(codeInfo);
    }

    @Override
    public UnsignedWord getCodeAndDataMemorySize(CodeInfo codeInfo) {
        return CodeInfoAccess.getCodeSize(codeInfo).add(CodeInfoAccess.getCodeAndDataMemorySize(codeInfo));
    }

    @Override
    public UnsignedWord getNativeMetadataSize(CodeInfo codeInfo) {
        return CodeInfoAccess.getNativeMetadataSize(codeInfo);
    }

    @Override
    public String getName(CodeInfo codeInfo) {
        return CodeInfoAccess.getName(codeInfo);
    }
}

@AutomaticFeature
class CodeInfoMemoryWalkerFeature implements Feature {
    @Override
    public void beforeAnalysis(BeforeAnalysisAccess access) {
        ImageSingletons.add(CodeInfoMemoryWalker.class, new CodeInfoMemoryWalker());
    }
}
